==> ra-sdk-0.0.1-20191227.014025-3-sources.jar: com/xdja/ra/utils/SdkBCUtils.java <==
package com.xdja.ra.utils;

import com.xdja.pki.gmssl.crypto.utils.GMSSLRSASignUtils;
import com.xdja.pki.gmssl.crypto.utils.GMSSLSM2SignUtils;
import com.xdja.pki.gmssl.x509.utils.bean.GMSSLSignatureAlgorithm;
import com.xdja.ra.asn1.RsaObjectIdentifiers;
import com.xdja.ra.asn1.SM2ObjectIdentifiers;
import com.xdja.ra.constant.SdkConstants;

import java.security.PrivateKey;
import java.security.PublicKey;

/**
 * @author wly
 */
public class SdkBCUtils {

    /**
     * BC证书链验签
     *
     * @param protectionAlgId 保护密钥算法oid
     * @param publicKey
     * @param sourceData
     * @param signData
     * @return
     * @throws Exception
     */
    public static boolean verifyCertByBC(String protectionAlgId, PublicKey publicKey, byte[] sourceData, byte[] signData) throws Exception {
        boolean verifyResult = false;
        if (SM2ObjectIdentifiers.sm2SignWithSm3.getId().equalsIgnoreCase(protectionAlgId)) {
            verifyResult = GMSSLSM2SignUtils.verifyByBC(publicKey, sourceData, signData);
        } else if (RsaObjectIdentifiers.sha1WithRSA.getId().equalsIgnoreCase(protectionAlgId)) {
            verifyResult = GMSSLRSASignUtils.verifyByBC(GMSSLSignatureAlgorithm.SHA1_WITH_RSA.getSigAlgName(), publicKey, sourceData, signData);
        } else if (RsaObjectIdentifiers.sha256WithRSA.getId().equalsIgnoreCase(protectionAlgId)) {
            verifyResult = GMSSLRSASignUtils.verifyByBC(GMSSLSignatureAlgorithm.SHA256_WITH_RSA.getSigAlgName(), publicKey, sourceData, signData);
        }

        return verifyResult;
    }


}

==> ra-sdk-1.0.5-20200922.061634-2-sources.jar: com/xdja/ra/utils/SdkBCUtils.java <==
package com.xdja.ra.utils;

import com.xdja.pki.gmssl.core.utils.GMSSLBCSignUtils;
import com.xdja.pki.gmssl.crypto.utils.GMSSLRSASignUtils;
import com.xdja.pki.gmssl.crypto.utils.GMSSLSM2SignUtils;
import com.xdja.pki.gmssl.x509.utils.bean.GMSSLSignatureAlgorithm;
import com.xdja.ra.asn1.RsaObjectIdentifiers;
import com.xdja.ra.asn1.SM2ObjectIdentifiers;

import java.security.PublicKey;

/**
 * @author wly
 */
public class SdkBCUtils {

    /**
     * BC证书链验签
     *
     * @param protectionAlgId 保护密钥算法oid
     * @param publicKey
     * @param sourceData
     * @param signData
     * @return
     * @throws Exception
     */
    public static boolean verifyCertByBC(String protectionAlgId, PublicKey publicKey, byte[] sourceData, byte[] signData) throws Exception {
        boolean verifyResult = false;
        if (SM2ObjectIdentifiers.sm2SignWithSm3.getId().equalsIgnoreCase(protectionAlgId)) {
            verifyResult = GMSSLSM2SignUtils.verifyByBC(publicKey, sourceData, signData);
        } else if (RsaObjectIdentifiers.sha1WithRSA.getId().equalsIgnoreCase(protectionAlgId)) {
            verifyResult = GMSSLRSASignUtils.verifyByBC(GMSSLSignatureAlgorithm.SHA1_WITH_RSA.getSigAlgName(), publicKey, sourceData, signData);
        } else if (RsaObjectIdentifiers.sha256WithRSA.getId().equalsIgnoreCase(protectionAlgId)) {
            verifyResult = GMSSLRSASignUtils.verifyByBC(GMSSLSignatureAlgorithm.SHA256_WITH_RSA.getSigAlgName(), publicKey, sourceData, signData);
        }else {
            verifyResult =  GMSSLBCSignUtils.verifySignature(GMSSLSignatureAlgorithm.SHA256_WITH_ECDSA.getSigAlgName(), publicKey, sourceData, signData);

        }

        return verifyResult;
    }


}
